##  Step 1. Create Your First Project Roadmap With Milestones
Creating a high-level roadmap that showcases your Initiatives and their defined Milestones is a key way to demonstrate progress in your business. This serves as the foundational step, paving the way for defining Transformations later on, that help you move towards the completion of an Initiative. Incorporating Milestones into your Initiatives will be a quick win with SAP LeanIX Architecture and Road Map Planning.
Here is the high-level step-by-step process to build a roadmap report containing initiatives and milestones:
  1. Create Initiative (Project) Fact Sheets to capture the details of your transformation initiatives. For more information about modeling the Initiative Fact Sheet, see [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.").
  2. Add important Milestones to your Initiatives. To learn how to add and manage Milestones, see [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports.").
  3. Ensure that your Initiatives have the following attributes and relations filled:
    1. Affected Applications
    2. Affected Business Capabilities
    3. Objectives being supported
    4. Additionally, the Business Value and Project Risk
  4. Create a Project Roadmap Report for your Initiatives. To learn how to work with Roadmap reports, see [Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report?locale=en-US&state=PRODUCTION&version=CLOUD).


With these steps, you have created your first Project/Initiative Roadmap report. It will provide an initial overview of planned projects, affected applications, and potential milestones for teams to accomplish. It helps in identifying project dependencies, so you can start involving the right teams in the conversation.
![Project Roadmap Report with Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274def2f7a441014a9dfdcf7444dfe1d_LowRes.png)
Project Roadmap Report with Milestones
